@@ -1,6 +1,6 @@
 package Git::More;
 # ABSTRACT: A Git extension with some goodies for hook developers
-$Git::More::VERSION = '1.11.0';
+$Git::More::VERSION = '1.11.1';
 use strict;
 use warnings;
 
@@ -473,8 +473,7 @@ sub blob {
 
         # Create temporary file and copy contents to it
         open my $tmp, '>:', $filepath ## no critic (RequireBriefOpen)
-            or git->error(__PACKAGE__, "Internal error: can't create file '$filepath': $!")
-                and return;
+            or throw Error::Simple("Internal error: can't create file '$filepath': $!");
         my ($pipe, $ctx) = $git->command_output_pipe(qw/cat-file blob/, $blob);
         my $read;
         while ($read = sysread $pipe, my $buffer, 64 * 1024) {
@@ -483,15 +482,13 @@ sub blob {
             while ($length) {
                 my $written = syswrite $tmp, $buffer, $length, $offset;
                 defined $written
-                    or $git->error(__PACKAGE__, "Internal error: can't write to '$filepath': $!")
-                        and return;
+                    or throw Error::Simple("Internal error: can't write to '$filepath': $!");
                 $length -= $written;
                 $offset += $written;
             }
         }
         defined $read
-            or $git->error(__PACKAGE__, "Internal error: can't read from git cat-file pipe: $!")
-                and return;
+            or throw Error::Simple("Internal error: can't read from git cat-file pipe: $!");
         $git->command_close_pipe($pipe, $ctx);
         $tmp->close();
         $cache->{$blob} = $filepath;
@@ -563,7 +560,7 @@ Git::More - A Git extension with some goodies for hook developers
 
 =head1 VERSION
 
-version 1.11.0
+version 1.11.1
 
 =head1 SYNOPSIS
 
@@ -947,6 +944,10 @@ destroyed.
 Any remaining ARGS are passed as arguments to C<File::Temp::newdir> so that you
 can have more control over the temporary file creation.
 
+If REV:FILE does not exist or if there is any other error while trying to
+fetch its contents the method throws a Git::Simple or a Git::Error::Command
+exception.
+
 =head2 file_size REV FILE
 
 This method returns the size (in bytes) of FILE (a path relative to the
